# OBJ - timestamped JSON objects
#
# obj/__init__.py
#
# Copyright 2017,2018 B.H.J Thate
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy 
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights 
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is 
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice don't have to be included.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
# THE SOFTWARE.
#
# 08-02-2018 As the creator of this file, I disclaim all rights on this file. 
#
# Bart Thate
# Heerhugowaard
# The Netherlands

"""
    object class to save/load json files.
    if a pathname is not provided a timestamp filename is provided, for example:
    the cfg.workdir variable in this module is prepended to a filename.

"""

from obj.base import Object

class Collection(Object):

    """ List of Objects. """

    def __init__(self, *args, **kwargs):
        super().__init__(self, *args, **kwargs)
        self.counter = 0

    def __iter__(self, *args, **kwargs):
        return self
        
    def __next__(self):
        for k, v in self.items():
            if type(k) == int:
                yield v

    def append(self, value):
        self[self.counter] = value
        self.counter += 1
        return self

    def remove(self, value):
        nr = 0
        for i in range(self.counter-1, -1, -1):
            if self[i] == value:
                del self[i]
                nr += 1
        self.counter -= nr
  