# OBJBOT - Framework to program bots !!
#
# bot/fleet.py
#
# Copyright 2017,2018 B.H.J Thate
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy 
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights 
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is 
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice don't have to be included.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
# THE SOFTWARE.
#
# 9-1-2018 As the creator of this file, I disclaim all rights on this file. 
#
# Bart Thate
# Heerhugowaard
# The Netherlands

"""  fleet module.  """

from obj.base import Object

class Fleet(Object):

    bots = []

    def __iter__(self):
        for bot in self.bots:
            yield bot

    def announce(self, txt):
        for bot in self.bots:
            bot.announce(txt)

    def delete(self, bot):
        if bot in self.bots:
            self.bots.remove(bot)
    
    def get_bot(self, id):
        for bot in self.bots:
            if id in bot.id:
                return bot

    def get_bots(self, id):
        for bot in self.bots:
            if id.lower() in bot.id.lower():
                yield bot

    def get_origin(self, nick):
        """ query bot in the fleet for a nick/origin match. Returns the origin. """
        for bot in self.bots:
            try:
                return bot._userhosts[nick]
            except (KeyError, AttributeError):
                pass

    def register(self, bot):
        self.bots.append(bot)

    def say_id(self, id, channel, txt, type):
        """ echo text to channel on bot matching the given id. """
        bots = self.get_bots(id)
        for bot in bots:
            if bot.id == id:
                bot.say(channel, txt, type)
