# OBJ - timestamped JSON objects
#
# obj/utils.py
#
# Copyright 2017,2018 B.H.J Thate
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy 
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights 
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is 
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice don't have to be included.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
# THE SOFTWARE.
#
# 01-03-2018 As the creator of this file, I disclaim all rights on this file. 
#
# Bart Thate
# Heerhugowaard
# The Netherlands

""" utility module. """

## imports

from obj.base import cfg, Object, __version__
from obj.loader import Loader
from obj.log import level
from obj.shell import parse_cli
from obj.trace import get_exception
from obj.users import Users

import logging
import obj

## vars

loader = Loader()
users = Users()

## functions

def services():
    """ start the sevices provided with the -i argument. """
    modnames = cfg.init.split(",")
    for name in modnames:
        try:
            mod = loader.direct(name)
        except ModuleNotFoundError:
            continue
        try:
            mod.start()
        except:
            logging.error(get_exception())    

def start(*args, **kwargs):
    """ run basic configuration tasks.. """
    cfg.update(parse_cli(*args, **kwargs))
    if cfg.banner:
        print("%s %s\n" % (cfg.name,  kwargs.get("version", __version__)))
    if cfg.level:
        level(cfg.level, form="plain")
    loader.walk("obj")
    users.uber("root@shell")
    if cfg.init:
        services()
    return cfg

def stripped(jid):
    """ strip trailing part of a JID, the part after the / """
    try:
        return str(jid).split("/")[0]
    except:
        return str(jid)
